==> exa-0.4.2.tar.gz: exa-0.4.2/README.md <==
[![exa logo](docs/source/static/logo.png)](https://exa-analytics.github.io) 

*A framework for data science*


# Installation
[![conda Badge](https://anaconda.org/exaanalytics/exa/badges/installer/conda.svg)](https://conda.anaconda.org/exaanalytics)  
[![pypi badge](https://badge.fury.io/py/exa.svg)](https://badge.fury.io/py/exa)  
Exa is available through [anaconda](https://www.continuum.io/downloads)

    $ conda install -c exaanalytics exa

or [pypi](https://pypi.python.org/pypi).

    $ pip install exa


# Getting Started
[![gitter](https://badges.gitter.im/exa-analytics/exa.svg)](https://gitter.im/exa-analytics/exa)  

See [docs](https://exa-analytics.github.io/exatomic/) for usage. 

Building the docs requires [sphinx](http://www.sphinx-doc.org/en/stable). On Linux or Mac:

    $ cd docs
    $ make html

On Windows:

    $ cd docs
    $ ./make.bat html


# Development
[![Travis-CI](https://travis-ci.org/exa-analytics/exa.svg?branch=master)](https://travis-ci.org/exa-analytics/exa)

[![AppVeyor](https://ci.appveyor.com/api/projects/status/j6h8pb23xduq5vqs?svg=true)](https://ci.appveyor.com/project/avmarchenko/exa)

[![Coveralls](https://coveralls.io/repos/github/exa-analytics/exa/badge.svg)](https://coveralls.io/github/exa-analytics/exa)

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/d7f1c1b3e8f14153b67d54f7f7ccdd05)](https://www.codacy.com/app/exa-analytics/exa-org?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=exa-analytics/exa&amp;utm_campaign=Badge_Grade)

For a development ready installation:

    $ git clone https://github.com/exa-analytics/exa.git
    $ cd exa
    $ pip install -e .


# Reference
[![DOI](https://zenodo.org/badge/23807/exa-analytics/exa.svg)](https://zenodo.org/badge/latestdoi/23807/exa-analytics/exa)  


# Legal
[![Apache License 2.0](http://img.shields.io/:license-apache-blue.svg?style=flat-square)](http://www.apache.org/licenses/LICENSE-2.0)  
Copyright (c) 2015-2018, Exa Analytics Development Team  
Distributed under the terms of the Apache License 2.0

==> exa-0.5.23.tar.gz: exa-0.5.23/README.md <==
[![exa logo](docs/source/static/logo.png)](https://exa-analytics.github.io) 

*A framework for data engineering and science*


# Installation
[![conda Badge](https://anaconda.org/exaanalytics/exa/badges/installer/conda.svg)](https://conda.anaconda.org/exaanalytics)  
[![pypi badge](https://badge.fury.io/py/exa.svg)](https://badge.fury.io/py/exa)  
Exa is available through [anaconda](https://www.continuum.io/downloads)

    $ conda install -c exaanalytics exa

or [pypi](https://pypi.python.org/pypi).

    $ pip install exa


# Getting Started
See [docs](https://exa-analytics.github.io/exa/) for usage. 

Building the docs requires [sphinx](http://www.sphinx-doc.org/en/stable). On Linux or Mac:

    $ ./make-docs.sh

On Windows:

    $ make-docs.bat


# Development
[![Travis-CI](https://travis-ci.org/exa-analytics/exa.svg?branch=master)](https://travis-ci.org/exa-analytics/exa)

[![AppVeyor](https://ci.appveyor.com/api/projects/status/9ufeeu5p623sifmr/branch/master?svg=true)](https://ci.appveyor.com/project/avmarchenko/exa/branch/master)

[![Coveralls](https://coveralls.io/repos/github/exa-analytics/exa/badge.svg)](https://coveralls.io/github/exa-analytics/exa)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/ed53a521ec4f46fbb62abee528b8b4bc)](https://www.codacy.com/gh/exa-analytics/exa?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=exa-analytics/exa&amp;utm_campaign=Badge_Grade)

For a development ready installation:

    $ git clone https://github.com/exa-analytics/exa.git
    $ cd exa
    $ python setup.py develop


# Reference
[![DOI](https://zenodo.org/badge/23807/exa-analytics/exa.svg)](https://zenodo.org/badge/latestdoi/23807/exa-analytics/exa)  


# Legal
[![Apache License 2.0](http://img.shields.io/:license-apache-blue.svg?style=flat-square)](http://www.apache.org/licenses/LICENSE-2.0)  
Copyright (c) 2015-2020, Exa Analytics Development Team  
Distributed under the terms of the Apache License 2.0
